@@ -28,8 +28,4 @@ class KCE():
         if len(list(self.function_description.keys())) >= int(order)+1 > 0:
             print(self.function_description[list(self.function_description.keys())[int(order)-1]])
         else:
-            print("범위를 넘어섰습니다.")
-
-if __name__ == "__main__":
-    CS = KCE()
-    CS.help(1)
\ No newline at end of file
+            print("범위를 넘어섰습니다.")
\ No newline at end of file
